Index: DamEngine/trunk/src/Deltares.DamEngine.Interface.Tests/TestFiles/Invoer10.xml
===================================================================
diff -u -r1105 -r1170
--- DamEngine/trunk/src/Deltares.DamEngine.Interface.Tests/TestFiles/Invoer10.xml (.../Invoer10.xml) (revision 1105)
+++ DamEngine/trunk/src/Deltares.DamEngine.Interface.Tests/TestFiles/Invoer10.xml (.../Invoer10.xml) (revision 1170)
@@ -1,21 +1,25 @@
-
+
-
+
+
-
+
+
-
+
+
-
+
+
Index: DamEngine/trunk/src/Deltares.DamEngine.Interface.Tests/MacroStabilityTests.cs
===================================================================
diff -u -r1169 -r1170
--- DamEngine/trunk/src/Deltares.DamEngine.Interface.Tests/MacroStabilityTests.cs (.../MacroStabilityTests.cs) (revision 1169)
+++ DamEngine/trunk/src/Deltares.DamEngine.Interface.Tests/MacroStabilityTests.cs (.../MacroStabilityTests.cs) (revision 1170)
@@ -526,11 +526,14 @@
}
[Test]
- public void TestRunMacroStabilityDeltaDijkForbiddenZoneBishop()
+ public void TestRunMacroStabilityInvoer10ForbiddenZoneBishop()
{
// Expected results are determined by running dam\dam clients\DamUI\trunk\data\DamEngineTestProjects\DeltaDijk_zonering_BI
// with Dam Classic rev.1059
- // Two locations with same profile
+ // Select locations DWP_10_2 and DWP_10_6
+ // Analysis type "No adaption"
+ // Calculation options: Stability Inside - Bishop
+ // This tests two locations with same profile
// But first location with Zone Areas and second location with Forbidden Zone
const string calcDir = "TestOutStabForbiddenZoneBishop";
if (Directory.Exists(calcDir))
@@ -526,11 +526,14 @@
{
- // Expected results are determined by running dam\dam clients\DamUI\trunk\data\DamEngineTestProjects\DeltaDijk_zonering_BI
+ // Expected results are determined by running dam\dam clients\DamUI\trunk\data\DamEngineTestProjects\Invoer10\ZoneType.damx
// with Dam Classic rev.1059